@@ -13,7 +13,7 @@ class SqlcmdOperator(BashOperator):
     sql_command = "/opt/mssql-tools/bin/sqlcmd -b -C -S {{ params.host }} -U {{ params.login }} -P {{ params.password }} -i {{ params.file }} "
 
     @apply_defaults
-    def __init__(self, task_id, mssql_conn_id, sql_folder, sql_file, *args, **kwargs):
+    def __init__(self, *, mssql_conn_id, sql_folder, sql_file, **kwargs):
 
         db = BaseHook.get_connection(mssql_conn_id)
 
@@ -24,7 +24,7 @@ class SqlcmdOperator(BashOperator):
             "file": self.sql_script_path(sql_folder, sql_file),
         }
 
-        super(SqlcmdOperator, self).__init__(task_id, bash_command=self.sql_command, params=params, *args, **kwargs)
+        super().__init__(bash_command=self.sql_command, params=params, **kwargs)
 
     def sql_script_path(self, sql_folder, sql_file):
         """Returns the corrected file path with quotation marks."""
